==> kadu_0.10.1.orig.tar.bz2: kadu-0.10.1/plugins/docking/translations/docking_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>@default</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Tacka systemowa</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>Start docked</source>
        <translation>Uruchom zminimalizowany</translation>
    </message>
    <message>
        <source>Show tooltip in tray</source>
        <translation>Pokaż podpowiedź w tacce systemowej</translation>
    </message>
    <message>
        <source>New message tray icon</source>
        <translation>Ikona nowej wiadomości</translation>
    </message>
    <message>
        <source>Blinking Envelope</source>
        <translation>Mrugająca</translation>
    </message>
    <message>
        <source>Static Envelope</source>
        <translation>Statyczna</translation>
    </message>
    <message>
        <source>Animated Envelope</source>
        <translation>Animowana</translation>
    </message>
</context>
<context>
    <name>DockingManager</name>
    <message>
        <source>Current status:
%1</source>
        <translation>Aktualny status:
%1</translation>
    </message>
    <message>
        <source>

Description:
%2</source>
        <translation>

Opis:
%2</translation>
    </message>
    <message>
        <source>&amp;Restore</source>
        <translation>P&amp;rzywróć</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Minimalizuj</translation>
    </message>
    <message>
        <source>&amp;Exit Kadu</source>
        <translation>&amp;Zakończ Kadu</translation>
    </message>
</context>
</TS>

==> kadu_0.11.2.orig.tar.bz2: kadu-0.11.2/plugins/docking/translations/docking_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>@default</name>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Tray</source>
        <translation>Tacka systemowa</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>Start docked</source>
        <translation>Uruchom zminimalizowany</translation>
    </message>
    <message>
        <source>Show tooltip in tray</source>
        <translation>Pokaż podpowiedź w tacce systemowej</translation>
    </message>
    <message>
        <source>New chat tray icon</source>
        <translation>Ikona nowej rozmowy</translation>
    </message>
    <message>
        <source>Blinking Envelope</source>
        <translation>Mrugająca</translation>
    </message>
    <message>
        <source>Static Envelope</source>
        <translation>Statyczna</translation>
    </message>
    <message>
        <source>Animated Envelope</source>
        <translation>Animowana</translation>
    </message>
</context>
<context>
    <name>DockingManager</name>
    <message>
        <source>Current status:
%1</source>
        <translation>Aktualny status:
%1</translation>
    </message>
    <message>
        <source>

Description:
%2</source>
        <translation>

Opis:
%2</translation>
    </message>
    <message>
        <source>&amp;Restore</source>
        <translation>P&amp;rzywróć</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Minimalizuj</translation>
    </message>
    <message>
        <source>&amp;Exit Kadu</source>
        <translation>&amp;Zakończ Kadu</translation>
    </message>
</context>
</TS>
